==> GFS-4.1.0.tar.gz: GFS-4.1.0/src/tools/mangle_fest/do_hole.c <==
/******************************************************************************
*******************************************************************************
**
**    Copyright 2001 Sistina Software, Inc.
**
**    This is free software released under the GNU General Public License.
**    There is no warranty for this software.  See the file COPYING for
**    details.
**
**    See the file CONTRIBUTORS for a list of contributors.
**
**    This file is maintained by:
**      Kenneth W. Preslan <kpreslan@sistina.com>
** 
**    Module name: 
**
**    Description:
**
*******************************************************************************
******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>



#define T (1)
#define F (0)

#ifdef linux
long long int llseek(int, long long int, int);
#define LLSEEK(x, y, z) llseek((x), (y), (z))
#endif  /*  linux  */




int main(int argc, char *argv[])
{
  int fd;
  unsigned long long int off, out;
  char buf[256] = "boo";


  if (argc < 3)
  {
    fputs("do_hole filename size\n", stderr);
    exit(EXIT_FAILURE);
  }


  off = atoll(argv[2]);

  fd = creat(argv[1], 0644);
  if (fd < 0)
  {
    fprintf(stderr, "do_hole:  error opening %s:  %s\n", 
	    argv[1], strerror(errno));
    exit(EXIT_FAILURE);
  }


  out = LLSEEK(fd, off, SEEK_SET);
  if (off != out)
  {
    fprintf(stderr, "do_hole:  error doing lseek():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  if (write(fd, buf, strlen(buf)) < 0)
  {
    fprintf(stderr, "do_hole:  error doing write():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  if (close(fd) < 0)
  {
    fprintf(stderr, "do_hole:  error doing close():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  exit(EXIT_SUCCESS);
}

==> GFS-4.1.1.tar.gz: GFS-4.1.1/src/tools/mangle_fest/do_hole.c <==
/******************************************************************************
*******************************************************************************
**
**    Copyright 2001 Sistina Software, Inc.
**
**    This is free software released under the GNU General Public License.
**    There is no warranty for this software.  See the file COPYING for
**    details.
**
**    See the file CONTRIBUTORS for a list of contributors.
**
**    This file is maintained by:
**      Kenneth W. Preslan <kpreslan@sistina.com>
** 
**    Module name: 
**
**    Description:
**
*******************************************************************************
******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>



#define T (1)
#define F (0)





int main(int argc, char *argv[])
{
  int fd;
  unsigned long long int off, out;
  char buf[256] = "boo";


  if (argc < 3)
  {
    fputs("do_hole filename size\n", stderr);
    exit(EXIT_FAILURE);
  }


  off = atoll(argv[2]);

  fd = creat(argv[1], 0644);
  if (fd < 0)
  {
    fprintf(stderr, "do_hole:  error opening %s:  %s\n", 
	    argv[1], strerror(errno));
    exit(EXIT_FAILURE);
  }


  out = lseek(fd, off, SEEK_SET);
  if (off != out)
  {
    fprintf(stderr, "do_hole:  error doing lseek():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  if (write(fd, buf, strlen(buf)) < 0)
  {
    fprintf(stderr, "do_hole:  error doing write():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  if (close(fd) < 0)
  {
    fprintf(stderr, "do_hole:  error doing close():  %s\n", 
	    strerror(errno));
    exit(EXIT_FAILURE);
  }


  exit(EXIT_SUCCESS);
}
